@@ -866,6 +866,26 @@ void WMSetUDSearchList(WMUserDefaults *database, WMPropList *list);
 extern char *WMUserDefaultsDidChangeNotification;
 
 
+/* ---[ WINGs/menuparser.c ]---------------------------------------------- */
+
+
+typedef struct w_menu_parser *WMenuParser;
+
+
+WMenuParser WMenuParserCreate(const char *file_name, void *file, const char *include_default_paths);
+
+void WMenuParserRegisterSimpleMacro(WMenuParser parser, const char *name, const char *value);
+
+void WMenuParserError(WMenuParser parser, const char *msg, ...)
+	__attribute__ ((format (printf, 2, 3)));
+
+const char *WMenuParserGetFilename(WMenuParser parser);
+
+Bool WMenuParserGetLine(WMenuParser parser, char **title, char **command, char **parameter, char **shortcut);
+
+void WMenuParserDelete(WMenuParser parser);
+
+
 /*-------------------------------------------------------------------------*/
 
 /* Global variables */
