@@ -1,8 +1,8 @@
 /*
  *  Window Maker window manager
- * 
- *  Copyright (c) 1997, 1998 Alfredo K. Kojima
- * 
+ *
+ *  Copyright (c) 1997-2003 Alfredo K. Kojima
+ *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -13,10 +13,9 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, 
- *  USA.
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef WMACTIONS_H_
@@ -24,9 +23,19 @@
 
 #include "window.h"
 
-#define MAX_HORIZONTAL 	1
-#define MAX_VERTICAL 	2
-#define MAX_IGNORE_XINERAMA 4
+#define MAX_HORIZONTAL         (1 << 0)
+#define MAX_VERTICAL           (1 << 1)
+#define MAX_LEFTHALF           (1 << 2)
+#define MAX_RIGHTHALF          (1 << 3)
+#define MAX_MAXIMUS            (1 << 4)
+#define MAX_IGNORE_XINERAMA    (1 << 5)
+#define MAX_KEYBOARD           (1 << 6)
+
+#define SAVE_GEOMETRY_X        (1 << 0)
+#define SAVE_GEOMETRY_Y        (1 << 1)
+#define SAVE_GEOMETRY_WIDTH    (1 << 2)
+#define SAVE_GEOMETRY_HEIGHT   (1 << 3)
+#define SAVE_GEOMETRY_ALL      SAVE_GEOMETRY_X | SAVE_GEOMETRY_Y | SAVE_GEOMETRY_WIDTH | SAVE_GEOMETRY_HEIGHT
 
 void wSetFocusTo(WScreen *scr, WWindow *wwin);
 
@@ -41,22 +50,22 @@ void wUnshadeWindow(WWindow *wwin);
 void wIconifyWindow(WWindow *wwin);
 void wDeiconifyWindow(WWindow *wwin);
 
-#ifndef LITE
 void wSelectWindows(WScreen *scr, XEvent *ev);
-#endif
 
 void wSelectWindow(WWindow *wwin, Bool flag);
 void wUnselectWindows(WScreen *scr);
 
 void wMaximizeWindow(WWindow *wwin, int directions);
 void wUnmaximizeWindow(WWindow *wwin);
+void handleMaximize(WWindow *wwin, int directions);
 
+void wHideAll(WScreen *src);
 void wHideOtherApplications(WWindow *wwin);
 void wShowAllWindows(WScreen *scr);
 
 void wHideApplication(WApplication *wapp);
-void wUnhideApplication(WApplication *wapp, Bool miniwindows, 
-			Bool bringToCurrentWS);
+void wUnhideApplication(WApplication *wapp, Bool miniwindows,
+                        Bool bringToCurrentWS);
 
 void wRefreshDesktop(WScreen *scr);
 
@@ -64,4 +73,11 @@ void wArrangeIcons(WScreen *scr, Bool arrangeAll);
 
 void wMakeWindowVisible(WWindow *wwin);
 
+void wFullscreenWindow(WWindow *wwin);
+void wUnfullscreenWindow(WWindow *wwin);
+
+void animateResize(WScreen *scr, int x, int y, int w, int h, int fx, int fy, int fw, int fh);
+void update_saved_geometry(WWindow *wwin);
+
 #endif
+
