@@ -26,6 +26,9 @@
 #include <X11/Xutil.h>
 #include <stdlib.h>
 #include <string.h>
+#include <unistd.h>
+#include <sys/stat.h>
+#include <errno.h>
 
 #include "WindowMaker.h"
 #include "window.h"
@@ -35,13 +38,14 @@
 #include "actions.h"
 #include "stacking.h"
 #include "dock.h"
-#include "funcs.h"
+#include "main.h"
 #include "defaults.h"
 #include "workspace.h"
 #include "superfluous.h"
 #include "menu.h"
 #include "framewin.h"
 #include "dialog.h"
+#include "xinerama.h"
 #include "client.h"
 #ifdef XDND
 #include "xdnd.h"
@@ -55,82 +59,230 @@
 /**** Global variables ****/
 extern Cursor wCursor[WCUR_LAST];
 extern WPreferences wPreferences;
+extern WDDomain *WDWindowAttributes;
+extern XContext wWinContext;
 
 #define MOD_MASK       wPreferences.modifier_mask
 
 void appIconMouseDown(WObjDescriptor * desc, XEvent * event);
 static void iconDblClick(WObjDescriptor * desc, XEvent * event);
 static void iconExpose(WObjDescriptor * desc, XEvent * event);
+static void wApplicationSaveIconPathFor(char *iconPath, char *wm_instance, char *wm_class);
+static WAppIcon *wAppIconCreate(WWindow * leader_win);
+static void add_to_appicon_list(WScreen *scr, WAppIcon *appicon);
+static void remove_from_appicon_list(WScreen *scr, WAppIcon *appicon);
 
-WAppIcon *wAppIconCreateForDock(WScreen * scr, char *command, char *wm_instance, char *wm_class, int tile)
+/* This function is used if the application is a .app. It checks if it has an icon in it
+ * like for example /usr/local/GNUstep/Applications/WPrefs.app/WPrefs.tiff
+ */
+void wApplicationExtractDirPackIcon(WScreen * scr, char *path, char *wm_instance, char *wm_class)
 {
-	WAppIcon *dicon;
-	char *path;
+	char *iconPath = NULL;
+	char *tmp = NULL;
 
-	dicon = wmalloc(sizeof(WAppIcon));
-	wretain(dicon);
-	dicon->yindex = -1;
-	dicon->xindex = -1;
+	if (strstr(path, ".app")) {
+		tmp = wmalloc(strlen(path) + 16);
 
-	dicon->prev = NULL;
-	dicon->next = scr->app_icon_list;
-	if (scr->app_icon_list)
-		scr->app_icon_list->prev = dicon;
+		if (scr->flags.supports_tiff) {
+			strcpy(tmp, path);
+			strcat(tmp, ".tiff");
+			if (access(tmp, R_OK) == 0)
+				iconPath = tmp;
+		}
 
-	scr->app_icon_list = dicon;
+		if (!iconPath) {
+			strcpy(tmp, path);
+			strcat(tmp, ".xpm");
+			if (access(tmp, R_OK) == 0)
+				iconPath = tmp;
+		}
 
-	if (command)
-		dicon->command = wstrdup(command);
+		if (!iconPath)
+			wfree(tmp);
 
-	if (wm_class)
-		dicon->wm_class = wstrdup(wm_class);
-
-	if (wm_instance)
-		dicon->wm_instance = wstrdup(wm_instance);
-
-	path = wDefaultGetIconFile(scr, wm_instance, wm_class, True);
-	if (!path && command) {
-		wApplicationExtractDirPackIcon(scr, command, wm_instance, wm_class);
-		path = wDefaultGetIconFile(scr, wm_instance, wm_class, False);
+		if (iconPath) {
+			wApplicationSaveIconPathFor(iconPath, wm_instance, wm_class);
+			wfree(iconPath);
+		}
 	}
-
-	if (path)
-		path = FindImage(wPreferences.icon_path, path);
-
-	dicon->icon = wIconCreateWithIconFile(scr, path, tile);
-	if (path)
-		wfree(path);
-#ifdef XDND
-	wXDNDMakeAwareness(dicon->icon->core->window);
-#endif
-
-	/* will be overriden by dock */
-	dicon->icon->core->descriptor.handle_mousedown = appIconMouseDown;
-	dicon->icon->core->descriptor.handle_expose = iconExpose;
-	dicon->icon->core->descriptor.parent_type = WCLASS_APPICON;
-	dicon->icon->core->descriptor.parent = dicon;
-	AddToStackList(dicon->icon->core);
-
-	return dicon;
 }
 
-WAppIcon *wAppIconCreate(WWindow * leader_win)
+WAppIcon *wAppIconCreateForDock(WScreen *scr, char *command, char *wm_instance, char *wm_class, int tile)
 {
 	WAppIcon *aicon;
-	WScreen *scr = leader_win->screen_ptr;
 
 	aicon = wmalloc(sizeof(WAppIcon));
 	wretain(aicon);
-
 	aicon->yindex = -1;
 	aicon->xindex = -1;
 
-	aicon->prev = NULL;
-	aicon->next = scr->app_icon_list;
-	if (scr->app_icon_list)
-		scr->app_icon_list->prev = aicon;
+	add_to_appicon_list(scr, aicon);
 
-	scr->app_icon_list = aicon;
+	if (command)
+		aicon->command = wstrdup(command);
+
+	if (wm_class)
+		aicon->wm_class = wstrdup(wm_class);
+
+	if (wm_instance)
+		aicon->wm_instance = wstrdup(wm_instance);
+
+	aicon->icon = icon_create_for_dock(scr, command, wm_instance, wm_class, tile);
+
+#ifdef XDND
+	wXDNDMakeAwareness(aicon->icon->core->window);
+#endif
+
+	/* will be overriden by dock */
+	aicon->icon->core->descriptor.handle_mousedown = appIconMouseDown;
+	aicon->icon->core->descriptor.handle_expose = iconExpose;
+	aicon->icon->core->descriptor.parent_type = WCLASS_APPICON;
+	aicon->icon->core->descriptor.parent = aicon;
+	AddToStackList(aicon->icon->core);
+
+	return aicon;
+}
+
+void makeAppIconFor(WApplication *wapp)
+{
+	/* If app_icon, work is done, return */
+	if (wapp->app_icon)
+		return;
+
+	/* Create the icon */
+	wapp->app_icon = wAppIconCreate(wapp->main_window_desc);
+	wIconUpdate(wapp->app_icon->icon, NULL);
+
+	/* Now, paint the icon */
+	if (!WFLAGP(wapp->main_window_desc, no_appicon))
+		paint_app_icon(wapp);
+}
+
+void unpaint_app_icon(WApplication *wapp)
+{
+	WAppIcon *aicon;
+	WScreen *scr;
+	WDock *clip;
+
+	if (!wapp || !wapp->app_icon)
+		return;
+
+	aicon = wapp->app_icon;
+
+	/* If the icon is docked, don't continue */
+	if (aicon->docked)
+		return;
+
+	scr = wapp->main_window_desc->screen_ptr;
+	clip = scr->workspaces[scr->current_workspace]->clip;
+
+	if (!clip || !aicon->attracted || !clip->collapsed)
+		XUnmapWindow(dpy, aicon->icon->core->window);
+
+	/* We want to avoid having it on the list  because otherwise
+	 * there will be a hole when the icons are arranged with
+	 * wArrangeIcons() */
+	remove_from_appicon_list(scr, aicon);
+
+	if (wPreferences.auto_arrange_icons && !aicon->attracted)
+		wArrangeIcons(scr, True);
+}
+
+void paint_app_icon(WApplication *wapp)
+{
+	WIcon *icon;
+	WScreen *scr = wapp->main_window_desc->screen_ptr;
+	WDock *clip = scr->workspaces[scr->current_workspace]->clip;
+	int x = 0, y = 0;
+	Bool update_icon = False;
+
+	if (!wapp || !wapp->app_icon)
+		return;
+
+	icon = wapp->app_icon->icon;
+	wapp->app_icon->main_window = wapp->main_window;
+
+	/* If the icon is docked, don't continue */
+	if (wapp->app_icon->docked)
+		return;
+
+	if (clip && clip->attract_icons && wDockFindFreeSlot(clip, &x, &y)) {
+		wapp->app_icon->attracted = 1;
+		if (!icon->shadowed) {
+			icon->shadowed = 1;
+			update_icon = True;
+		}
+		wDockAttachIcon(clip, wapp->app_icon, x, y, update_icon);
+	} else {
+		/* We must know if the icon is painted in the screen,
+		 * because if painted, then PlaceIcon will return the next
+		 * space on the screen, and the icon will move */
+		if (wapp->app_icon->next == NULL && wapp->app_icon->prev == NULL) {
+			PlaceIcon(scr, &x, &y, wGetHeadForWindow(wapp->main_window_desc));
+			wAppIconMove(wapp->app_icon, x, y);
+			wLowerFrame(icon->core);
+		}
+	}
+
+	/* If we want appicon (no_appicon is not set) and the icon is not
+	 * in the appicon_list, we must add it. Else, we want to avoid
+	 * having it on the list */
+	if (!WFLAGP(wapp->main_window_desc, no_appicon) &&
+	    wapp->app_icon->next == NULL && wapp->app_icon->prev == NULL)
+		add_to_appicon_list(scr, wapp->app_icon);
+
+	if (!clip || !wapp->app_icon->attracted || !clip->collapsed)
+		XMapWindow(dpy, icon->core->window);
+
+	if (wPreferences.auto_arrange_icons && !wapp->app_icon->attracted)
+		wArrangeIcons(scr, True);
+}
+
+void removeAppIconFor(WApplication *wapp)
+{
+	if (!wapp->app_icon)
+		return;
+
+	if (wPreferences.highlight_active_app)
+		wIconSetHighlited(wapp->app_icon->icon, False);
+	if (wapp->app_icon->docked && !wapp->app_icon->attracted) {
+		wapp->app_icon->running = 0;
+		/* since we keep it, we don't care if it was attracted or not */
+		wapp->app_icon->attracted = 0;
+		wapp->app_icon->icon->shadowed = 0;
+		wapp->app_icon->main_window = None;
+		wapp->app_icon->pid = 0;
+		wapp->app_icon->icon->owner = NULL;
+		wapp->app_icon->icon->icon_win = None;
+
+		/* Update the icon images */
+		wIconUpdate(wapp->app_icon->icon, NULL);
+
+		/* Paint it */
+		wAppIconPaint(wapp->app_icon);
+	} else if (wapp->app_icon->docked) {
+		wapp->app_icon->running = 0;
+		wDockDetach(wapp->app_icon->dock, wapp->app_icon);
+	} else {
+		wAppIconDestroy(wapp->app_icon);
+	}
+
+	wapp->app_icon = NULL;
+
+	if (wPreferences.auto_arrange_icons)
+		wArrangeIcons(wapp->main_window_desc->screen_ptr, True);
+}
+
+static WAppIcon *wAppIconCreate(WWindow *leader_win)
+{
+	WAppIcon *aicon;
+
+	aicon = wmalloc(sizeof(WAppIcon));
+	wretain(aicon);
+	aicon->yindex = -1;
+	aicon->xindex = -1;
+	aicon->prev = NULL;
+	aicon->next = NULL;
 
 	if (leader_win->wm_class)
 		aicon->wm_class = wstrdup(leader_win->wm_class);
@@ -138,7 +290,7 @@ WAppIcon *wAppIconCreate(WWindow * leader_win)
 	if (leader_win->wm_instance)
 		aicon->wm_instance = wstrdup(leader_win->wm_instance);
 
-	aicon->icon = wIconCreate(leader_win);
+	aicon->icon = icon_create_for_wwindow(leader_win);
 #ifdef XDND
 	wXDNDMakeAwareness(aicon->icon->core->window);
 #endif
@@ -150,7 +302,6 @@ WAppIcon *wAppIconCreate(WWindow * leader_win)
 	aicon->icon->core->descriptor.parent = aicon;
 	AddToStackList(aicon->icon->core);
 	aicon->icon->show_title = 0;
-	wIconUpdate(aicon->icon);
 
 	return aicon;
 }
@@ -173,16 +324,7 @@ void wAppIconDestroy(WAppIcon * aicon)
 	if (aicon->wm_class)
 		wfree(aicon->wm_class);
 
-	if (aicon == scr->app_icon_list) {
-		if (aicon->next)
-			aicon->next->prev = NULL;
-		scr->app_icon_list = aicon->next;
-	} else {
-		if (aicon->next)
-			aicon->next->prev = aicon->prev;
-		if (aicon->prev)
-			aicon->prev->next = aicon->next;
-	}
+	remove_from_appicon_list(scr, aicon);
 
 	aicon->destroyed = 1;
 	wrelease(aicon);
@@ -235,7 +377,7 @@ static void updateDockNumbers(WScreen * scr)
 }
 #endif				/* WS_INDICATOR */
 
-void wAppIconPaint(WAppIcon * aicon)
+void wAppIconPaint(WAppIcon *aicon)
 {
 	WApplication *wapp;
 	WScreen *scr = aicon->icon->core->screen_ptr;
@@ -275,20 +417,23 @@ void wAppIconPaint(WAppIcon * aicon)
 			       0, 0, wPreferences.icon_size, wPreferences.icon_size);
 }
 
-Bool wAppIconSave(WAppIcon *aicon)
+/* Save the application icon, if it's a dockapp then use it with dock = True */
+void save_appicon(WAppIcon *aicon, Bool dock)
 {
 	char *path;
 
-	if (!aicon->docked || aicon->attracted) return True;
+	if (!aicon)
+		return;
+
+	if (dock && (!aicon->docked || aicon->attracted))
+		return;
 
 	path = wIconStore(aicon->icon);
 	if (!path)
-		return False;
+		return;
 
 	wApplicationSaveIconPathFor(path, aicon->wm_instance, aicon->wm_class);
-
 	wfree(path);
-	return True;
 }
 
 #define canBeDocked(wwin)  ((wwin) && ((wwin)->wm_class||(wwin)->wm_instance))
@@ -345,7 +490,7 @@ static void unhideHereCallback(WMenu * menu, WMenuEntry * entry)
 	wUnhideApplication(wapp, False, True);
 }
 
-static void setIconCallback(WMenu * menu, WMenuEntry * entry)
+static void setIconCallback(WMenu *menu, WMenuEntry *entry)
 {
 	WAppIcon *icon = ((WApplication *) entry->clientdata)->app_icon;
 	char *file = NULL;
@@ -429,14 +574,14 @@ static void killCallback(WMenu * menu, WMenuEntry * entry)
 	WCHANGE_STATE(WSTATE_NORMAL);
 }
 
-static WMenu *createApplicationMenu(WScreen * scr)
+static WMenu *createApplicationMenu(WScreen *scr)
 {
 	WMenu *menu;
 
 	menu = wMenuCreate(scr, NULL, False);
-	wMenuAddCallback(menu, _("Launch"), relaunchCallback, NULL);
 	wMenuAddCallback(menu, _("Unhide Here"), unhideHereCallback, NULL);
 	wMenuAddCallback(menu, _("Hide"), hideCallback, NULL);
+	wMenuAddCallback(menu, _("Launch"), relaunchCallback, NULL);
 	wMenuAddCallback(menu, _("Set Icon..."), setIconCallback, NULL);
 	wMenuAddCallback(menu, _("Kill"), killCallback, NULL);
 
@@ -480,12 +625,12 @@ static void openApplicationMenu(WApplication * wapp, int x, int y)
 
 /******************************************************************/
 
-static void iconExpose(WObjDescriptor * desc, XEvent * event)
+static void iconExpose(WObjDescriptor *desc, XEvent *event)
 {
 	wAppIconPaint(desc->parent);
 }
 
-static void iconDblClick(WObjDescriptor * desc, XEvent * event)
+static void iconDblClick(WObjDescriptor *desc, XEvent *event)
 {
 	WAppIcon *aicon = desc->parent;
 	WApplication *wapp;
@@ -711,7 +856,7 @@ void appIconMouseDown(WObjDescriptor * desc, XEvent * event)
 				/* icon is trying to be docked */
 				SlideWindow(icon->core->window, x, y, shad_x, shad_y);
 				XUnmapWindow(dpy, scr->dock_shadow);
-				docked = wDockAttachIcon(scr->last_dock, aicon, ix, iy);
+				docked = wDockAttachIcon(scr->last_dock, aicon, ix, iy, False);
 				if (scr->last_dock->auto_collapse)
 					collapsed = 0;
 
@@ -759,3 +904,143 @@ void appIconMouseDown(WObjDescriptor * desc, XEvent * event)
 		}
 	}
 }
+
+/* This function save the application icon and store the path in the Dictionary */
+static void wApplicationSaveIconPathFor(char *iconPath, char *wm_instance, char *wm_class)
+{
+	WMPropList *dict = WDWindowAttributes->dictionary;
+	WMPropList *adict, *key, *iconk;
+	WMPropList *val;
+	char *tmp;
+
+	tmp = get_name_for_instance_class(wm_instance, wm_class);
+	key = WMCreatePLString(tmp);
+	wfree(tmp);
+
+	adict = WMGetFromPLDictionary(dict, key);
+	iconk = WMCreatePLString("Icon");
+
+	if (adict) {
+		val = WMGetFromPLDictionary(adict, iconk);
+	} else {
+		/* no dictionary for app, so create one */
+		adict = WMCreatePLDictionary(NULL, NULL);
+		WMPutInPLDictionary(dict, key, adict);
+		WMReleasePropList(adict);
+		val = NULL;
+	}
+
+	if (!val) {
+		val = WMCreatePLString(iconPath);
+		WMPutInPLDictionary(adict, iconk, val);
+		WMReleasePropList(val);
+	} else {
+		val = NULL;
+	}
+
+	WMReleasePropList(key);
+	WMReleasePropList(iconk);
+
+	if (val && !wPreferences.flags.noupdates)
+		UpdateDomainFile(WDWindowAttributes);
+}
+
+static WAppIcon *findDockIconFor(WDock *dock, Window main_window)
+{
+	WAppIcon *aicon = NULL;
+
+	aicon = wDockFindIconForWindow(dock, main_window);
+	if (!aicon) {
+		wDockTrackWindowLaunch(dock, main_window);
+		aicon = wDockFindIconForWindow(dock, main_window);
+	}
+	return aicon;
+}
+
+void create_appicon_from_dock(WWindow *wwin, WApplication *wapp, Window main_window)
+{
+	WScreen *scr = wwin->screen_ptr;
+	wapp->app_icon = NULL;
+
+	if (scr->last_dock)
+		wapp->app_icon = findDockIconFor(scr->last_dock, main_window);
+
+	/* check main dock if we did not find it in last dock */
+	if (!wapp->app_icon && scr->dock)
+		wapp->app_icon = findDockIconFor(scr->dock, main_window);
+
+	/* finally check clips */
+	if (!wapp->app_icon) {
+		int i;
+		for (i = 0; i < scr->workspace_count; i++) {
+			WDock *dock = scr->workspaces[i]->clip;
+			if (dock)
+				wapp->app_icon = findDockIconFor(dock, main_window);
+			if (wapp->app_icon)
+				break;
+		}
+	}
+
+	/* If created, then set some flags */
+	if (wapp->app_icon) {
+		WWindow *mainw = wapp->main_window_desc;
+
+		wapp->app_icon->running = 1;
+		wapp->app_icon->icon->owner = mainw;
+		if (mainw->wm_hints && (mainw->wm_hints->flags & IconWindowHint))
+			wapp->app_icon->icon->icon_win = mainw->wm_hints->icon_window;
+
+		/* Update the icon images */
+		wIconUpdate(wapp->app_icon->icon, NULL);
+
+		/* Paint it */
+		wAppIconPaint(wapp->app_icon);
+		save_appicon(wapp->app_icon, True);
+	}
+}
+
+/* Add the appicon to the appiconlist */
+static void add_to_appicon_list(WScreen *scr, WAppIcon *appicon)
+{
+	appicon->prev = NULL;
+	appicon->next = scr->app_icon_list;
+	if (scr->app_icon_list)
+		scr->app_icon_list->prev = appicon;
+
+	scr->app_icon_list = appicon;
+}
+
+/* Remove the appicon from the appiconlist */
+static void remove_from_appicon_list(WScreen *scr, WAppIcon *appicon)
+{
+	if (appicon == scr->app_icon_list) {
+		if (appicon->next)
+			appicon->next->prev = NULL;
+		scr->app_icon_list = appicon->next;
+	} else {
+		if (appicon->next)
+			appicon->next->prev = appicon->prev;
+		if (appicon->prev)
+			appicon->prev->next = appicon->next;
+	}
+
+	appicon->prev = NULL;
+	appicon->next = NULL;
+}
+
+/* Return the AppIcon associated with a given (Xlib) Window. */
+WAppIcon *wAppIconFor(Window window)
+{
+	WObjDescriptor *desc;
+
+	if (window == None)
+		return NULL;
+
+	if (XFindContext(dpy, window, wWinContext, (XPointer *) & desc) == XCNOENT)
+		return NULL;
+
+	if (desc->parent_type == WCLASS_APPICON || desc->parent_type == WCLASS_DOCK_ICON)
+		return desc->parent;
+
+	return NULL;
+}
