@@ -56,7 +56,7 @@
 #include "keybind.h"
 #include "xmodifier.h"
 #include "icon.h"
-#include "funcs.h"
+#include "main.h"
 #include "actions.h"
 #include "dock.h"
 #include "workspace.h"
@@ -204,6 +204,7 @@ static WOptionEnumeration sePlacements[] = {
 	{"Cascade", WPM_CASCADE, 0},
 	{"Random", WPM_RANDOM, 0},
 	{"Manual", WPM_MANUAL, 0},
+	{"Center", WPM_CENTER, 0},
 	{NULL, 0, 0}
 };
 
@@ -415,6 +416,8 @@ WDefaultEntry optionList[] = {
 	    &wPreferences.no_animations, getBool, NULL, NULL, NULL},
 	{"DontLinkWorkspaces", "NO", NULL,
 	    &wPreferences.no_autowrap, getBool, NULL, NULL, NULL},
+	{"HighlightActiveApp", "YES", NULL,
+	    &wPreferences.highlight_active_app, getBool, NULL, NULL, NULL},
 	{"AutoArrangeIcons", "NO", NULL,
 	    &wPreferences.auto_arrange_icons, getBool, NULL, NULL, NULL},
 	{"NoWindowOverDock", "NO", NULL,
@@ -681,7 +684,9 @@ WDefaultEntry optionList[] = {
 	{"DialogHistoryLines", "500", NULL,
 	    &wPreferences.history_lines, getInt, NULL, NULL, NULL},
 	{"CycleActiveHeadOnly", "NO", NULL,
-	    &wPreferences.cycle_active_head_only, getBool, NULL, NULL, NULL}
+	    &wPreferences.cycle_active_head_only, getBool, NULL, NULL, NULL},
+	{"CycleIgnoreMinimized", "NO", NULL,
+	    &wPreferences.cycle_ignore_minimized, getBool, NULL, NULL, NULL}
 };
 
 static void initDefaults()
@@ -803,7 +808,6 @@ WDDomain *wDefaultsInitDomain(char *domain, Bool requireDictionary)
 	WDDomain *db;
 	struct stat stbuf;
 	static int inited = 0;
-	char path[PATH_MAX];
 	char *the_path;
 	WMPropList *shared_dict = NULL;
 
@@ -832,32 +836,19 @@ WDDomain *wDefaultsInitDomain(char *domain, Bool requireDictionary)
 	}
 
 	/* global system dictionary */
-	snprintf(path, sizeof(path), "%s/%s/%s", SYSCONFDIR, GLOBAL_DEFAULTS_SUBDIR, domain);
-	if (stat(path, &stbuf) >= 0) {
-		shared_dict = WMReadPropListFromFile(path);
-		if (shared_dict) {
-			if (requireDictionary && !WMIsPLDictionary(shared_dict)) {
-				wwarning(_("Domain %s (%s) of global defaults database is corrupted!"),
-					 domain, path);
-				WMReleasePropList(shared_dict);
-				shared_dict = NULL;
-			} else {
-				if (db->dictionary && WMIsPLDictionary(shared_dict) &&
-				    WMIsPLDictionary(db->dictionary)) {
-					WMMergePLDictionaries(shared_dict, db->dictionary, True);
-					WMReleasePropList(db->dictionary);
-					db->dictionary = shared_dict;
-					if (stbuf.st_mtime > db->timestamp)
-						db->timestamp = stbuf.st_mtime;
-				} else if (!db->dictionary) {
-					db->dictionary = shared_dict;
-					if (stbuf.st_mtime > db->timestamp)
-						db->timestamp = stbuf.st_mtime;
-				}
-			}
-		} else {
-			wwarning(_("could not load domain %s from global defaults database (%s)"), domain, path);
-		}
+	shared_dict = readGlobalDomain(domain, requireDictionary);
+
+	if (shared_dict && db->dictionary && WMIsPLDictionary(shared_dict) &&
+	    WMIsPLDictionary(db->dictionary)) {
+		WMMergePLDictionaries(shared_dict, db->dictionary, True);
+		WMReleasePropList(db->dictionary);
+		db->dictionary = shared_dict;
+		if (stbuf.st_mtime > db->timestamp)
+			db->timestamp = stbuf.st_mtime;
+	} else if (!db->dictionary) {
+		db->dictionary = shared_dict;
+		if (stbuf.st_mtime > db->timestamp)
+			db->timestamp = stbuf.st_mtime;
 	}
 
 	return db;
@@ -878,17 +869,15 @@ void wReadStaticDefaults(WMPropList * dict)
 		else
 			plvalue = NULL;
 
-		if (!plvalue) {
-			/* no default in the DB. Use builtin default */
+		/* no default in the DB. Use builtin default */
+		if (!plvalue)
 			plvalue = entry->plvalue;
-		}
 
 		if (plvalue) {
 			/* convert data */
 			(*entry->convert) (NULL, entry, plvalue, entry->addr, &tdata);
-			if (entry->update) {
+			if (entry->update)
 				(*entry->update) (NULL, entry, tdata, entry->extra_data);
-			}
 		}
 	}
 }
@@ -962,39 +951,30 @@ void wDefaultsCheckDomains(void* arg)
 					dict = shared_dict;
 					shared_dict = NULL;
 				}
-				if (WDWindowAttributes->dictionary) {
+
+				if (WDWindowAttributes->dictionary)
 					WMReleasePropList(WDWindowAttributes->dictionary);
-				}
+
 				WDWindowAttributes->dictionary = dict;
 				for (i = 0; i < wScreenCount; i++) {
 					scr = wScreenWithNumber(i);
 					if (scr) {
-						RImage *image;
-
 						wDefaultUpdateIcons(scr);
 
 						/* Update the panel image if changed */
 						/* Don't worry. If the image is the same these
 						 * functions will have no performance impact. */
-						image = wDefaultGetImage(scr, "Logo", "WMPanel", wPreferences.icon_size);
-
-						if (!image) {
-							wwarning(_("could not load logo image for panels: %s"),
-								 RMessageForError(RErrorCode));
-						} else {
-							WMSetApplicationIconImage(scr->wmscreen, image);
-							RReleaseImage(image);
-						}
+						create_logo_image(scr);
 					}
 				}
 			}
 		} else {
 			wwarning(_("could not load domain %s from user defaults database"), "WMWindowAttributes");
 		}
+
 		WDWindowAttributes->timestamp = stbuf.st_mtime;
-		if (shared_dict) {
+		if (shared_dict)
 			WMReleasePropList(shared_dict);
-		}
 	}
 
 	if (stat(WDRootMenu->path, &stbuf) >= 0 && WDRootMenu->timestamp < stbuf.st_mtime) {
@@ -1006,9 +986,9 @@ void wDefaultsCheckDomains(void* arg)
 				wwarning(_("Domain %s (%s) of defaults database is corrupted!"),
 					 "WMRootMenu", WDRootMenu->path);
 			} else {
-				if (WDRootMenu->dictionary) {
+				if (WDRootMenu->dictionary)
 					WMReleasePropList(WDRootMenu->dictionary);
-				}
+
 				WDRootMenu->dictionary = dict;
 				wDefaultsMergeGlobalMenus(WDRootMenu);
 			}
@@ -1141,19 +1121,15 @@ void wReadDefaults(WScreen * scr, WMPropList * new_dict)
 	}
 }
 
-void wDefaultUpdateIcons(WScreen * scr)
+void wDefaultUpdateIcons(WScreen *scr)
 {
 	WAppIcon *aicon = scr->app_icon_list;
 	WWindow *wwin = scr->focused_window;
-	char *file;
 
 	while (aicon) {
-		file = wDefaultGetIconFile(scr, aicon->wm_instance, aicon->wm_class, False);
-		if ((file && aicon->icon->file && strcmp(file, aicon->icon->file) != 0)
-		    || (file && !aicon->icon->file)) {
-			wIconChangeImageFile(aicon->icon, file);
-			wAppIconPaint(aicon);
-		}
+		/* Get the application icon, default included */
+		wIconChangeImageFile(aicon->icon, NULL);
+		wAppIconPaint(aicon);
 		aicon = aicon->next;
 	}
 
@@ -1161,13 +1137,8 @@ void wDefaultUpdateIcons(WScreen * scr)
 		wClipIconPaint(scr->clip_icon);
 
 	while (wwin) {
-		if (wwin->icon && wwin->flags.miniaturized) {
-			file = wDefaultGetIconFile(scr, wwin->wm_instance, wwin->wm_class, False);
-			if ((file && wwin->icon->file && strcmp(file, wwin->icon->file) != 0)
-			    || (file && !wwin->icon->file)) {
-				wIconChangeImageFile(wwin->icon, file);
-			}
-		}
+		if (wwin->icon && wwin->flags.miniaturized)
+			wIconChangeImageFile(wwin->icon, NULL);
 		wwin = wwin->prev;
 	}
 }
@@ -2402,18 +2373,14 @@ static int setIconTile(WScreen * scr, WDefaultEntry * entry, WTexture ** texture
 
 	scr->icon_tile_pixmap = pixmap;
 
-	if (scr->def_icon_pixmap) {
-		XFreePixmap(dpy, scr->def_icon_pixmap);
-		scr->def_icon_pixmap = None;
-	}
-	if (scr->def_ticon_pixmap) {
-		XFreePixmap(dpy, scr->def_ticon_pixmap);
-		scr->def_ticon_pixmap = None;
+	if (scr->def_icon_rimage) {
+		RReleaseImage(scr->def_icon_rimage);
+		scr->def_icon_rimage = NULL;
 	}
 
-	if (scr->icon_back_texture) {
+	if (scr->icon_back_texture)
 		wTextureDestroy(scr, (WTexture *) scr->icon_back_texture);
-	}
+
 	scr->icon_back_texture = wTextureMakeSolid(scr, &((*texture)->any.color));
 
 	if (scr->clip_balloon)
