@@ -42,6 +42,7 @@
 #include "actions.h"
 #include "menu.h"
 #include "funcs.h"
+#include "main.h"
 #include "dialog.h"
 #include "keybind.h"
 #include "stacking.h"
@@ -64,6 +65,7 @@ static WMenu *readMenuPipe(WScreen * scr, char **file_name);
 static WMenu *readMenuFile(WScreen * scr, char *file_name);
 static WMenu *readMenuDirectory(WScreen * scr, char *title, char **file_name, char *command);
 static WMenu *configureMenu(WScreen * scr, WMPropList * definition, Bool includeGlobals);
+static void menu_parser_register_macros(WMenuParser parser);
 
 typedef struct Shortcut {
 	struct Shortcut *next;
@@ -409,7 +411,7 @@ static void removeShortcutsForMenu(WMenu * menu)
 	menu->menu->screen_ptr->flags.root_menu_changed_shortcuts = 1;
 }
 
-static Bool addShortcut(char *file, char *shortcutDefinition, WMenu * menu, WMenuEntry * entry)
+static Bool addShortcut(const char *file, char *shortcutDefinition, WMenu * menu, WMenuEntry * entry)
 {
 	Shortcut *ptr;
 	KeySym ksym;
@@ -758,7 +760,7 @@ static WMenuEntry *addWindowsMenu(WScreen * scr, WMenu * menu, char *title)
 }
 
 static WMenuEntry *addMenuEntry(WMenu * menu, char *title, char *shortcut, char *command,
-				char *params, char *file_name)
+				char *params, const char *file_name)
 {
 	WScreen *scr;
 	WMenuEntry *entry = NULL;
@@ -890,112 +892,15 @@ static void freeline(char *title, char *command, char *parameter, char *shortcut
 	wfree(shortcut);
 }
 
-static void separateline(char *line, char **title, char **command, char **parameter, char **shortcut)
+static WMenu *parseCascade(WScreen * scr, WMenu * menu, WMenuParser parser)
 {
-	char *suffix, *next = line;
-
-	*title = NULL;
-	*command = NULL;
-	*parameter = NULL;
-	*shortcut = NULL;
-
-	/* get the title */
-	*title = wtokennext(line, &next);
-	if (next == NULL)
-		return;
-	line = next;
-
-	/* get the command or shortcut keyword */
-	*command = wtokennext(line, &next);
-	if (next == NULL)
-		return;
-	line = next;
-
-	if (*command != NULL && strcmp(*command, "SHORTCUT") == 0) {
-		/* get the shortcut */
-		*shortcut = wtokennext(line, &next);
-		if (next == NULL)
-			return;
-		line = next;
-
-		/* get the command */
-		*command = wtokennext(line, &next);
-		if (next == NULL)
-			return;
-		line = next;
-	}
-
-	/* get the parameters */
-	suffix = wtrimspace(line);
-
-	/* should we keep this weird old behavior? */
-	if (suffix[0] == '"') {
-		*parameter = wtokennext(suffix, &next);
-		wfree(suffix);
-	} else {
-		*parameter = suffix;
-	}
-}
-
-static char *getLine(FILE * file, const char *file_name)
-{
-	char linebuf[MAXLINE];
-	char *line = NULL, *result = NULL;
-	size_t len;
-	int done;
-
-again:
-	done = 0;
-	while (!done && fgets(linebuf, sizeof(linebuf), file) != NULL) {
-		line = wtrimspace(linebuf);
-		len = strlen(line);
-
-		/* allow line wrapping */
-		if (len > 0 && line[len - 1] == '\\') {
-			line[len - 1] = '\0';
-		} else {
-			done = 1;
-		}
-
-		if (result == NULL) {
-			result = line;
-		} else {
-			if (strlen(result) < MAXLINE) {
-				result = wstrappend(result, line);
-			}
-			wfree(line);
-		}
-	}
-	if (!done || ferror(file)) {
-		wfree(result);
-		result = NULL;
-	} else if (result != NULL && (result[0] == 0 || result[0] == '#' ||
-		   (result[0] == '/' && result[1] == '/'))) {
-		wfree(result);
-		result = NULL;
-		goto again;
-	} else if (result != NULL && strlen(result) >= MAXLINE) {
-		wwarning(_("%s:maximal line size exceeded in menu config: %s"),
-			 file_name, line);
-		wfree(result);
-		result = NULL;
-		goto again;
-	}
-
-	return result;
-}
-
-static WMenu *parseCascade(WScreen * scr, WMenu * menu, FILE * file, char *file_name)
-{
-	char *line;
 	char *command, *params, *shortcut, *title;
 
-	while ((line = getLine(file, file_name)) != NULL) {
-		separateline(line, &title, &command, &params, &shortcut);
+	while (WMenuParserGetLine(parser, &title, &command, &params, &shortcut)) {
 
 		if (command == NULL || !command[0]) {
+			WMenuParserError(parser, _("missing command in menu config") );
 			freeline(title, command, params, shortcut);
-			wwarning(_("%s:missing command in menu config: %s"), file_name, line);
 			goto error;
 		}
 
@@ -1006,7 +911,7 @@ static WMenu *parseCascade(WScreen * scr, WMenu * menu, FILE * file, char *file_
 
 			cascade = wMenuCreate(scr, M_(title), False);
 			cascade->on_destroy = removeShortcutsForMenu;
-			if (parseCascade(scr, cascade, file, file_name) == NULL) {
+			if (!parseCascade(scr, cascade, parser)) {
 				wMenuDestroy(cascade, True);
 			} else {
 				wMenuEntrySetCascade(menu, wMenuAddCallback(menu, M_(title), NULL, NULL), cascade);
@@ -1017,12 +922,12 @@ static WMenu *parseCascade(WScreen * scr, WMenu * menu, FILE * file, char *file_
 			return menu;
 		} else {
 			/* normal items */
-			addMenuEntry(menu, M_(title), shortcut, command, params, file_name);
+			addMenuEntry(menu, M_(title), shortcut, command, params, WMenuParserGetFilename(parser));
 		}
 		freeline(title, command, params, shortcut);
 	}
 
-	wwarning(_("%s:syntax error in menu file:END declaration missing"), file_name);
+	WMenuParserError(parser, _("syntax error in menu file: END declaration missing") );
 
  error:
 	return NULL;
@@ -1032,72 +937,43 @@ static WMenu *readMenuFile(WScreen * scr, char *file_name)
 {
 	WMenu *menu = NULL;
 	FILE *file = NULL;
-	char *line;
+	WMenuParser parser;
 	char *command, *params, *shortcut, *title;
-	char cmd[MAXLINE];
-#ifdef USECPP
-	char *args;
-	int cpp = 0;
-#endif
-
-#ifdef USECPP
-	if (!wPreferences.flags.nocpp) {
-		args = MakeCPPArgs(file_name);
-		if (!args) {
-			wwarning(_("could not make arguments for menu file preprocessor"));
-		} else {
-			snprintf(cmd, sizeof(cmd), "%s %s %s", CPP_PATH, args, file_name);
-			wfree(args);
-			file = popen(cmd, "r");
-			if (!file) {
-				werror(_("%s:could not open/preprocess menu file"), file_name);
-			} else {
-				cpp = 1;
-			}
-		}
-	}
-#endif				/* USECPP */
 
+	file = fopen(file_name, "rb");
 	if (!file) {
-		file = fopen(file_name, "rb");
-		if (!file) {
-			werror(_("%s:could not open menu file"), file_name);
-			return NULL;
-		}
+		werror(_("%s:could not open menu file"), file_name);
+		return NULL;
 	}
+	parser = WMenuParserCreate(file_name, file, DEF_CONFIG_PATHS);
+	menu_parser_register_macros(parser);
 
-	while ((line = getLine(file, file_name)) != NULL) {
-		separateline(line, &title, &command, &params, &shortcut);
+	while (WMenuParserGetLine(parser, &title, &command, &params, &shortcut)) {
 
 		if (command == NULL || !command[0]) {
-			wwarning(_("%s:missing command in menu config: %s"), file_name, line);
+			WMenuParserError(parser, _("missing command in menu config") );
+			freeline(title, command, params, shortcut);
 			break;
 		}
 		if (strcasecmp(command, "MENU") == 0) {
 			menu = wMenuCreate(scr, M_(title), True);
 			menu->on_destroy = removeShortcutsForMenu;
-			if (!parseCascade(scr, menu, file, file_name)) {
+			if (!parseCascade(scr, menu, parser)) {
 				wMenuDestroy(menu, True);
+				menu = NULL;
 			}
+			freeline(title, command, params, shortcut);
 			break;
 		} else {
-			wwarning(_("%s:invalid menu file. MENU command is missing"), file_name);
+			WMenuParserError(parser, _("invalid menu file, MENU command is missing") );
+			freeline(title, command, params, shortcut);
 			break;
 		}
+		freeline(title, command, params, shortcut);
 	}
-	freeline(title, command, params, shortcut);
 
-#ifdef USECPP
-	if (cpp) {
-		if (pclose(file) == -1) {
-			werror(_("error reading preprocessed menu data"));
-		}
-	} else {
-		fclose(file);
-	}
-#else
+	WMenuParserDelete(parser);
 	fclose(file);
-#endif
 
 	return menu;
 }
@@ -1108,14 +984,11 @@ static WMenu *readMenuPipe(WScreen * scr, char **file_name)
 {
 	WMenu *menu = NULL;
 	FILE *file = NULL;
+	WMenuParser parser;
 	char *command, *params, *shortcut, *title;
-	char *line;
 	char *filename;
 	char flat_file[MAXLINE];
 	int i;
-#ifdef USECPP
-	char *args;
-#endif
 
 	flat_file[0] = '\0';
 
@@ -1125,53 +998,40 @@ static WMenu *readMenuPipe(WScreen * scr, char **file_name)
 	}
 	filename = flat_file + (flat_file[1] == '|' ? 2 : 1);
 
-#ifdef USECPP
-	if (!wPreferences.flags.nocpp) {
-		args = MakeCPPArgs(filename);
-		if (!args) {
-			wwarning(_("could not make arguments for menu file preprocessor"));
-		} else {
-			snprintf(command, sizeof(command), "%s | %s %s", filename, CPP_PATH, args);
-
-			wfree(args);
-			file = popen(command, "r");
-			if (!file) {
-				werror(_("%s:could not open/preprocess menu file"), filename);
-			}
-		}
-	}
-#endif				/* USECPP */
-
+	file = popen(filename, "r");
 	if (!file) {
-		file = popen(filename, "rb");
-
-		if (!file) {
-			werror(_("%s:could not open menu file"), filename);
-			return NULL;
-		}
+		werror(_("%s:could not open menu file"), filename);
+		return NULL;
 	}
+	parser = WMenuParserCreate(flat_file, file, DEF_CONFIG_PATHS);
+	menu_parser_register_macros(parser);
 
-	while ((line = getLine(file, filename)) != NULL) {
-		separateline(line, &title, &command, &params, &shortcut);
+	while (WMenuParserGetLine(parser, &title, &command, &params, &shortcut)) {
 
 		if (command == NULL || !command[0]) {
-			wwarning(_("%s:missing command in menu config: %s"), filename, line);
+			WMenuParserError(parser, _("missing command in menu config") );
+			freeline(title, command, params, shortcut);
 			break;
 		}
 		if (strcasecmp(command, "MENU") == 0) {
 			menu = wMenuCreate(scr, M_(title), True);
 			menu->on_destroy = removeShortcutsForMenu;
-			if (!parseCascade(scr, menu, file, filename)) {
+			if (!parseCascade(scr, menu, parser)) {
 				wMenuDestroy(menu, True);
+				menu = NULL;
 			}
+			freeline(title, command, params, shortcut);
 			break;
 		} else {
-			wwarning(_("%s:no title given for the root menu"), filename);
+			WMenuParserError(parser, _("no title given for the root menu") );
+			freeline(title, command, params, shortcut);
 			break;
 		}
-	}
-	freeline(title, command, params, shortcut);
 
+		freeline(title, command, params, shortcut);
+	}
+
+	WMenuParserDelete(parser);
 	pclose(file);
 
 	return menu;
@@ -1190,6 +1050,34 @@ static int myCompare(const void *d1, const void *d2)
 	return strcmp(p1->name, p2->name);
 }
 
+/***** Preset some macro for file parser *****/
+static void menu_parser_register_macros(WMenuParser parser)
+{
+	Visual *visual;
+	char buf[32];
+
+	// Used to return CPP verion, now returns wmaker's version
+	WMenuParserRegisterSimpleMacro(parser, "__VERSION__", VERSION);
+
+	// All macros below were historically defined by WindowMaker
+	visual = DefaultVisual(dpy, DefaultScreen(dpy));
+	snprintf(buf, sizeof(buf), "%d", visual->class);
+	WMenuParserRegisterSimpleMacro(parser, "VISUAL", buf);
+
+	snprintf(buf, sizeof(buf), "%d", DefaultDepth(dpy, DefaultScreen(dpy)) );
+	WMenuParserRegisterSimpleMacro(parser, "DEPTH", buf);
+
+	snprintf(buf, sizeof(buf), "%d", WidthOfScreen(DefaultScreenOfDisplay(dpy)) );
+	WMenuParserRegisterSimpleMacro(parser, "SCR_WIDTH", buf);
+
+	snprintf(buf, sizeof(buf), "%d", HeightOfScreen(DefaultScreenOfDisplay(dpy)) );
+	WMenuParserRegisterSimpleMacro(parser, "SCR_HEIGHT", buf);
+
+	WMenuParserRegisterSimpleMacro(parser, "DISPLAY", XDisplayName(DisplayString(dpy)) );
+
+	WMenuParserRegisterSimpleMacro(parser, "WM_VERSION", "\"" VERSION "\"");
+}
+
 /************  Menu Configuration From Directory   *************/
 
 static Bool isFilePackage(char *file)
