@@ -229,14 +229,13 @@ typedef struct _WScreen {
 
     struct RImage *icon_tile;
     struct RImage *clip_tile;
-    Pixmap icon_tile_pixmap;	       /* for app supplied icons */
 
-    Pixmap def_icon_pixmap;	       /* default icons */
-    Pixmap def_ticon_pixmap;
+    Pixmap icon_tile_pixmap;		/* For app supplied icons */
+
+    struct RImage *def_icon_rimage;	/* Default RImage icon */
 
     struct WDialogData *dialog_data;
 
-
     struct W_GeometryView *gview;      /* size/position view */
 
     /* state and other informations */
@@ -310,7 +309,7 @@ WScreen *wScreenSearchForRootWindow(Window window);
 WScreen *wScreenForWindow(Window window);   /* slower than above functions */
 
 void wScreenFinish(WScreen *scr);
-
 void wScreenUpdateUsableArea(WScreen *scr);
 
+void create_logo_image(WScreen *scr);
 #endif
