@@ -38,6 +38,11 @@
 #include "workspace.h"
 #include "framewin.h"
 
+#define IS_GNUSTEP_MENU(w) ((w)->wm_gnustep_attr && \
+	((w)->wm_gnustep_attr->flags & GSWindowLevelAttr) && \
+	((w)->wm_gnustep_attr->window_level == WMMainMenuWindowLevel || \
+	 (w)->wm_gnustep_attr->window_level == WMSubmenuWindowLevel))
+
 /********* Global Variables *******/
 extern WPreferences wPreferences;
 
