@@ -13,10 +13,9 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
- *  USA.
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef WMWINDOW_H_
@@ -110,6 +109,7 @@ typedef struct {
     unsigned int no_shadeable:1;
     unsigned int omnipresent:1;
     unsigned int skip_window_list:1;
+    unsigned int skip_switchpanel:1;
     unsigned int floating:1;	       /* put in WMFloatingLevel */
     unsigned int sunken:1;	       /* put in WMSunkenLevel */
     unsigned int no_bind_keys:1;       /* intercept wm kbd binds
@@ -125,6 +125,8 @@ typedef struct {
     unsigned int dont_move_off:1;
 
     unsigned int no_focusable:1;
+    unsigned int focus_across_wksp:1;   /* let wmaker switch workspace to follow
+					 * a focus request */
 
     unsigned int always_user_icon:1;   /* ignore client IconPixmap or
                                         * IconWindow */
@@ -135,11 +137,6 @@ typedef struct {
     unsigned int dont_save_session:1;  /* do not save app's state in session */
 
     unsigned int full_maximize:1;
-
-#ifdef VIRTUAL_DESKTOP
-    unsigned int virtual_stick:1;
-#endif
-
     /*
      * emulate_app_icon must be automatically disabled for apps that can
      * generate their own appicons and for apps that have no_appicon=1
@@ -159,9 +156,6 @@ typedef struct {
     unsigned int SAVE_YOURSELF:1;
     /* WindowMaker specific */
     unsigned int MINIATURIZE_WINDOW:1;
-#ifdef MONITOR_HEARTBEAT
-    unsigned int HEARTBEAT:1;
-#endif
 } WProtocols;
 
 
@@ -181,168 +175,134 @@ typedef struct WFakeGroupLeader {
  * structure created when it's being first mapped.
  */
 typedef struct WWindow {
-    struct WWindow *prev;	       /* window focus list */
-    struct WWindow *next;
+	struct WWindow *prev;			/* window focus list */
+	struct WWindow *next;
 
-    WScreen *screen_ptr;	       /* pointer to the screen structure */
-    WWindowAttributes user_flags;      /* window attribute flags set by user */
-    WWindowAttributes defined_user_flags;/* mask for user_flags */
-    WWindowAttributes client_flags;    /* window attribute flags set by app
-                                        * initialized with global defaults */
+	WScreen *screen_ptr; 			/* pointer to the screen structure */
+	WWindowAttributes user_flags;		/* window attribute flags set by user */
+	WWindowAttributes defined_user_flags;	/* mask for user_flags */
+	WWindowAttributes client_flags;		/* window attribute flags set by app
+						 * initialized with global defaults */
 
-    struct InspectorPanel *inspector;  /*  pointer to attribute editor panel */
+	struct InspectorPanel *inspector;	/* pointer to attribute editor panel */
 
-    struct WFrameWindow *frame;	       /* the frame window */
-    int frame_x, frame_y;	       /* position of the frame in root*/
+	struct WFrameWindow *frame;		/* the frame window */
+	int frame_x, frame_y;			/* position of the frame in root*/
 
-    struct {
-        int x, y;
-        unsigned int width, height;    /* original geometry of the window */
-    } old_geometry;		       /* (before things like maximize) */
+	struct {
+		int x, y;
+		unsigned int width, height;	/* original geometry of the window */
+	} old_geometry;				/* (before things like maximize) */
 
-    struct {
-        int x, y;
-        unsigned int width, height;    /* original geometry of the window */
-    } bfs_geometry;		       /* (before fullscreen) */
+	struct {
+		int x, y;
+		unsigned int width, height;	/* original geometry of the window */
+	} bfs_geometry;				/* (before fullscreen) */
 
-    /* client window info */
-    short old_border_width;	       /* original border width of client_win*/
-    Window client_win;		       /* the window we're managing */
-    WObjDescriptor client_descriptor;  /* dummy descriptor for client */
-    struct {
-        int x, y;		       /* position of *client* relative
-                                        * to root */
-        unsigned int width, height;    /* size of the client window */
-    } client;
+	int maximus_x;				/* size after Maximusizing */
+	int maximus_y;
 
-    XSizeHints *normal_hints;	       /* WM_NORMAL_HINTS */
-    XWMHints *wm_hints;		       /* WM_HINTS (optional) */
-    char *wm_instance;		       /* instance of WM_CLASS */
-    char *wm_class;    		       /* class of WM_CLASS */
-    GNUstepWMAttributes *wm_gnustep_attr;/* GNUstep window attributes */
+	/* client window info */
+	short old_border_width;			/* original border width of client_win*/
+	Window client_win;			/* the window we're managing */
+	WObjDescriptor client_descriptor;	/* dummy descriptor for client */
+	struct {
+		int x, y;			/* position of *client* relative
+						 * to root */
+		unsigned int width, height;	/* size of the client window */
+	} client;
 
-    int state;			       /* state as in ICCCM */
+	XSizeHints *normal_hints;		/* WM_NORMAL_HINTS */
+	XWMHints *wm_hints;			/* WM_HINTS (optional) */
+	char *wm_instance;			/* instance of WM_CLASS */
+	char *wm_class;				/* class of WM_CLASS */
+	GNUstepWMAttributes *wm_gnustep_attr;	/* GNUstep window attributes */
 
-    Window transient_for;	       /* WM_TRANSIENT_FOR */
+	int state;				/* state as in ICCCM */
 
-    WFakeGroupLeader *fake_group;      /* Fake group leader for grouping into
-                                          a single appicon */
-    Window group_id;		       /* the leader window of the group */
-    Window client_leader;	       /* WM_CLIENT_LEADER if not
-                                          internal_window */
+	Window transient_for;			/* WM_TRANSIENT_FOR */
 
-    Window main_window;		       /* main window for the application */
+	WFakeGroupLeader *fake_group;		/* Fake group leader for grouping into
+						 * a single appicon */
+	Window group_id;			/* the leader window of the group */
+	Window client_leader;			/* WM_CLIENT_LEADER if not
+						 * internal_window */
 
-    Window orig_main_window;   	       /* original main window of application.
-                                          used for the shared appicon thing */
+	Window main_window;			/* main window for the application */
+	Window orig_main_window;		/* original main window of application.
+						 * used for the shared appicon thing */
 
-    int cmap_window_no;
-    Window *cmap_windows;
+	int cmap_window_no;
+	Window *cmap_windows;
 
-    /* protocols */
-    WProtocols protocols;	       /* accepted WM_PROTOCOLS */
+	/* protocols */
+	WProtocols protocols;			/* accepted WM_PROTOCOLS */
 
-    FocusMode focus_mode;	       /* type of keyboard input focus */
+	FocusMode focus_mode;			/* type of keyboard input focus */
 
-    long event_mask;		       /* the event mask thats selected */
+	long event_mask;			/* the event mask thats selected */
 
-#ifdef MONITOR_HEARTBEAT
-    time_t last_beat;
-#endif
-    struct {
-        /* state flags */
-        unsigned int mapped:1;
-        unsigned int focused:1;
-        unsigned int miniaturized:1;
-        unsigned int hidden:1;
-        unsigned int shaded:1;
-        unsigned int maximized:2;
-        unsigned int fullscreen:1;
-        unsigned int omnipresent:1;
-
-        unsigned int semi_focused:1;
-        /* window type flags */
-        unsigned int urgent:1;	       /* if wm_hints says this is urgent */
+	/* state flags */
+	struct {
+		unsigned int mapped:1;
+		unsigned int focused:1;
+		unsigned int miniaturized:1;
+		unsigned int hidden:1;
+		unsigned int shaded:1;
+		unsigned int maximized:5;
+		unsigned int old_maximized:5;
+		unsigned int fullscreen:1;
+		unsigned int omnipresent:1;
+		unsigned int semi_focused:1;
+		/* window type flags */
+		unsigned int urgent:1;		/* if wm_hints says this is urgent */
 #ifdef SHAPE
-        unsigned int shaped:1;
+		unsigned int shaped:1;
 #endif
 
-        /* info flags */
-        unsigned int is_gnustep:1;  /* 1 if the window belongs to a GNUstep
-                                       app */
+		/* info flags */
+		unsigned int is_gnustep:1;	/* 1 if the window belongs to a GNUstep
+						 * app */
+		unsigned int is_dockapp:1;	/* 1 if the window belongs to a DockApp */
 
-        unsigned int buttons_dont_fit:1;
-        unsigned int rebuild_texture:1;  /* the window was resized and
-                                          * gradients should be re-rendered */
-        unsigned int needs_full_repaint:1;/* does a full repaint of the
-                                           * window next time it's painted */
-        unsigned int icon_moved:1;     /* icon for this window was moved
-                                        * by the user */
-        unsigned int selected:1;       /* multiple window selection */
-        unsigned int skip_next_animation:1;
-        unsigned int internal_window:1;
-        unsigned int changing_workspace:1;
+		unsigned int icon_moved:1;	/* icon for this window was moved
+						 * by the user */
+		unsigned int selected:1;	/* multiple window selection */
+		unsigned int skip_next_animation:1;
+		unsigned int internal_window:1;
+		unsigned int changing_workspace:1;
 
-        unsigned int inspector_open:1; /* attrib inspector is already open */
+		unsigned int inspector_open:1;	/* attrib inspector is already open */
 
-        unsigned int destroyed:1;      /* window was already destroyed */
+		unsigned int destroyed:1;	/* window was already destroyed */
+		unsigned int menu_open_for_me:1;/* window commands menu */
+		unsigned int obscured:1;	/* window is obscured */
 
-        unsigned int menu_open_for_me:1;   /* window commands menu */
+		unsigned int net_skip_pager:1;
+		unsigned int net_handle_icon:1;
+		unsigned int net_show_desktop:1;
+		unsigned int net_has_title:1;	/* use netwm version of WM_NAME */
+		unsigned int net_has_icon_title:1;
+	} flags;				/* state of the window */
 
-        unsigned int waiting_save_ack:1;   /* waiting for SAVE_YOURSELF ack */
-
-        unsigned int obscured:1;       /* window is obscured */
-
-        unsigned int dragged_while_fmaximized;
-
-        unsigned int user_changed_width:1;
-        unsigned int user_changed_height:1;
-        unsigned int wm_name_changed:1;
-
-#ifdef NETWM_HINTS
-        unsigned int net_state_from_client:1; /* state hint was set by client */
-        unsigned int net_skip_pager:1;
-        unsigned int net_handle_icon:1;
-        unsigned int net_show_desktop:1;
-        unsigned int net_has_title:1; /* use netwm version of WM_NAME */
-        unsigned int net_has_icon_title:1;
-#endif
-    } flags;		/* state of the window */
-
-    struct WIcon *icon;		       /* icon info for the window */
-    int icon_x, icon_y;		       /* position of the icon */
-#ifdef NETWM_HINTS
-    int icon_w, icon_h;
-    RImage *net_icon_image;
-    Atom type;
-#endif
+	struct WIcon *icon;			/* Window icon when miminized
+						 * else is NULL! */
+	int icon_x, icon_y;			/* position of the icon */
+	int icon_w, icon_h;
+	RImage *net_icon_image;			/* Window Image */
+	Atom type;
 } WWindow;
 
-
-#define HAS_TITLEBAR(w)	    (!(WFLAGP((w), no_titlebar) || (w)->flags.fullscreen))
-#define HAS_RESIZEBAR(w)    (!(WFLAGP((w), no_resizebar) || (w)->flags.fullscreen))
-#define HAS_BORDER(w)	    (!(WFLAGP((w), no_border) || (w)->flags.fullscreen))
-#define IS_MOVABLE(w)	    (!(WFLAGP((w), no_movable) || (w)->flags.fullscreen))
-#define IS_RESIZABLE(w)    (!(WFLAGP((w), no_resizable) || (w)->flags.fullscreen))
-
-#ifdef VIRTUAL_DESKTOP
-# define IS_VSTUCK(w)	    (WFLAGP((w), virtual_stick) || (w)->flags.fullscreen)
-#endif
-
-/* XXX: CHECK THIS,.. IT SEEMED WEIRD TO ME!!! */
-#define IS_OMNIPRESENT(w) ((w)->flags.omnipresent | WFLAGP(w, omnipresent))
-
-#define WINDOW_LEVEL(w) ((w)->frame->core->stacking->window_level)
-
-#define IS_GNUSTEP_MENU(w) ((w)->wm_gnustep_attr && \
-    ((w)->wm_gnustep_attr->flags & GSWindowLevelAttr) && \
-    ((w)->wm_gnustep_attr->window_level==WMMainMenuWindowLevel || \
-     (w)->wm_gnustep_attr->window_level==WMSubmenuWindowLevel))
-
+#define HAS_TITLEBAR(w)		(!(WFLAGP((w), no_titlebar) || (w)->flags.fullscreen))
+#define HAS_RESIZEBAR(w)	(!(WFLAGP((w), no_resizebar) || (w)->flags.fullscreen))
+#define HAS_BORDER(w)		(!(WFLAGP((w), no_border) || (w)->flags.fullscreen))
+#define IS_MOVABLE(w)		(!(WFLAGP((w), no_movable) || (w)->flags.fullscreen))
+#define IS_RESIZABLE(w)		(!(WFLAGP((w), no_resizable) || (w)->flags.fullscreen))
+#define IS_OMNIPRESENT(w)	((w)->flags.omnipresent | WFLAGP(w, omnipresent))
+#define WINDOW_LEVEL(w)		((w)->frame->core->stacking->window_level)
 
 /*
  * Changes to this must update wWindowSaveState/getSavedState
- *
  */
 typedef struct WSavedState {
     int workspace;
@@ -357,7 +317,6 @@ typedef struct WSavedState {
     unsigned window_shortcuts; /* mask like 1<<shortcut_number */
 } WSavedState;
 
-
 typedef struct WWindowState {
     char *instance;
     char *class;
@@ -367,13 +326,10 @@ typedef struct WWindowState {
     struct WWindowState *next;
 } WWindowState;
 
-
 typedef void* WMagicNumber;
 
-
-
 void wWindowDestroy(WWindow *wwin);
-WWindow *wWindowCreate();
+WWindow *wWindowCreate(void);
 
 #ifdef SHAPE
 void wWindowSetShape(WWindow *wwin);
@@ -388,9 +344,9 @@ void wWindowFocus(WWindow *wwin, WWindow *owin);
 void wWindowUnfocus(WWindow *wwin);
 
 void wWindowUpdateName(WWindow *wwin, char *newTitle);
-void wWindowConstrainSize(WWindow *wwin, int *nwidth, int *nheight);
-void wWindowCropSize(WWindow *wwin, int maxw, int maxh,
-                     int *nwidth, int *nheight);
+void wWindowConstrainSize(WWindow *wwin, unsigned int *nwidth, unsigned int *nheight);
+void wWindowCropSize(WWindow *wwin, unsigned int maxw, unsigned int maxh,
+                     unsigned int *nwidth, unsigned int *nheight);
 void wWindowConfigure(WWindow *wwin, int req_x, int req_y,
                       int req_width, int req_height);
 
@@ -425,8 +381,6 @@ void wWindowMap(WWindow *wwin);
 
 void wWindowUnmap(WWindow *wwin);
 
-Bool wWindowCanReceiveFocus(WWindow *wwin);
-
 void wWindowDeleteSavedStatesForPID(pid_t pid);
 
 WMagicNumber wWindowAddSavedState(char *instance, char *class, char *command,
@@ -439,5 +393,4 @@ void wWindowDeleteSavedState(WMagicNumber id);
 Bool wWindowObscuresWindow(WWindow *wwin, WWindow *obscured);
 
 void wWindowSetOmnipresent(WWindow *wwin, Bool flag);
-
 #endif
